@@ -2,27 +2,27 @@
 
 import pytest
 
-from shv import (
+from shv.rpcdef import (
     RpcError,
-    RpcInternalError,
-    RpcInvalidParamsError,
-    RpcInvalidRequestError,
-    RpcMethodCallCancelledError,
+    RpcInvalidParamError,
+    RpcLoginRequiredError,
     RpcMethodCallExceptionError,
-    RpcMethodCallTimeoutError,
     RpcMethodNotFoundError,
-    RpcParseError,
+    RpcNotImplementedError,
+    RpcRequestInvalidError,
+    RpcTryAgainLaterError,
+    RpcUserIDRequiredError,
 )
 
 errors = (
-    RpcInternalError,
-    RpcInvalidParamsError,
-    RpcInvalidRequestError,
-    RpcMethodCallCancelledError,
-    RpcMethodCallExceptionError,
-    RpcMethodCallTimeoutError,
     RpcMethodNotFoundError,
-    RpcParseError,
+    RpcInvalidParamError,
+    RpcMethodCallExceptionError,
+    RpcLoginRequiredError,
+    RpcUserIDRequiredError,
+    RpcNotImplementedError,
+    RpcTryAgainLaterError,
+    RpcRequestInvalidError,
 )
 
 
